# Welcome to `oobabot`

**`oobabot`** is a Discord bot which can connect this AI with your Discord server.

## Step 1. Create a Bot Account

First, you'll need to generate a Discord bot token.  This is a secret key that
authenticates your bot to Discord.

1. Log in to [Discord's Developer Portal](https://discord.com/developers/applications)
1. Choose **`New Application`**
1. Give your bot a name.  This name will be visible to users.
1. Choose **`Bot`** from the left-hand menu.
1. Under **`Privileged Gateway Intents`** enable:
    - **`SERVER MEMBERS INTENT: ON`**
    - **`MESSAGE CONTENT INTENT: ON`**
1. Hit "Save Changes".
1. Hit **`Reset Token`** and copy the token

## Step 2. Enter your Bot Token

**`Paste your token`** below, then **`Save`**.

{{TOKEN_INPUT_BOX}}

## Step 3. Invite your Bot
